package	jp.co.sds_corp.transfer.filter;

import jp.co.sds_corp.transfer.ReceiveEvent;
import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.AbstractService;

/**
* データのフィルタリングを行なうクラスの基底クラスです。
*/
public abstract class AbstractFilter extends AbstractService
		implements IFilter
{
	private static final long serialVersionUID = 1L;
	public static final int LOG_OFF		= -1;
	public static final int LOG_DEBUG	= 0;
	public static final int LOG_INFO	= 1;
	public static final int LOG_WARN	= 2;
	public static final int LOG_ERROR	= 3;
	public static final int LOG_FATAL	= 4;
	int		logLevel = LOG_INFO;

	/**
	* 指定された初期情報で初期化します。
	* @param	config	初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		String	var;
		var = config.get( "loglevel", "info" );
		if ( var.equals( "off" )) {
			logLevel = LOG_OFF;
		} else if ( var.equals( "info" )) {
			logLevel = LOG_INFO;
		} else if ( var.equals( "warn" )) {
			logLevel = LOG_WARN;
		} else if ( var.equals( "error" )) {
			logLevel = LOG_ERROR;
		} else if ( var.equals( "fatal" )) {
			logLevel = LOG_FATAL;
		} else {
			logLevel = LOG_INFO;
		}
	}

	/**
	* このサービスを開始します。
	*/
	public void start() {
	}

	/**
	* このサービスを停止します。
	*/
	public void stop() {
	}

	/**
	* データのフィルタリングを行なう
	* @param	e		データ変更イベント
	*/
	public abstract boolean isValid( ReceiveEvent e ) throws Exception;

	/**
	* データがフィルタリングの対象であるかチェックする。
	* @param	e		データ変更イベント
	*/
	public abstract boolean isTarget( ReceiveEvent e ) throws Exception;

	/**
	* ログ出力
	* @param	msg		メッセージ
	* @param	e		データ変更イベント
	*/
	public void putLog( String msg, ReceiveEvent e ) {
		String s = "data filtered." + msg + " filter=" + this + " " + e;
		switch ( logLevel ) {
		case LOG_DEBUG: CmnLog.debug( this, s ); break;
		case LOG_INFO:  CmnLog.info( this, s ); break;
		case LOG_WARN:  CmnLog.warn( this, s ); break;
		case LOG_ERROR: CmnLog.error( this, s ); break;
		case LOG_FATAL: CmnLog.fatal( this, s ); break;
		}
	}

	/**
	* ログ出力レベル(logLevel)を設定します。
	* @param	var		設定するデータ
	*/
	public void setLogLevel( int var ) {
		this.logLevel = var ;
	}
	/**
	* ログ出力レベル(logLevel)を取得します。
	* @return	logLevelの内容
	*/
	public int getLogLevel() {
		return logLevel;
	}

}
