package	jp.co.sds_corp.transfer.filter;

import java.util.Iterator;
import java.util.Vector;

import jp.co.sds_corp.transfer.ReceiveEvent;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* データソースのクラス名によってフィルタリングします。
source要素で指定されたデータソース以外のデータ受信イベントを排除します。
なお、source要素は複数指定することが可能です。
<P>
loglevel要素によって、このフィルタで排除されたデータ受信イベントのログ出力を
制御することができます。
localevel要素には、off,debug,info,warn,error,fatalの各レベルを指定可能です。
<PRE>
&lt;filter class="jp.co.sds_corp.transfer.filter.NameFilter"&gt;
	&lt;source&gt;jp.co.sds_corp.transfer.fx.source.DataSource&lt;/source&gt;
	&lt;loglevel&gt;info&lt;/loglevel&gt;
&lt;/filter&gt
</PRE>
*/
public class SourceFilter extends AbstractFilter
{
	private static final long serialVersionUID = 1L;
	Vector<String>	vecSrc;

	/**
	* 指定された初期情報で初期化します。
	* @param	config	初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		vecSrc = new Vector<String>();
		Iterator<IConfiguration> itr = config.getChilds( "source" );
		while ( itr.hasNext() ) {
			IConfiguration c = (IConfiguration )itr.next();
			vecSrc.add( c.get() );
		}
	}

	/**
	* データのフィルタリングを行なう
	* @param	e		データ受信イベント
	*/
	public boolean isValid( ReceiveEvent e ) throws Exception {
		for ( int i = 0; i < vecSrc.size(); i++ ) {
			String cls = e.getSource().getClass().getName();
			if ( cls.equals( (String )vecSrc.get( i ))) {
				return true;
			}
		}
		return false;
	}

	/**
	* データがフィルタリングの対象であるかチェックする。
	* @param	e		データ受信イベント
	*/
	public boolean isTarget( ReceiveEvent e ) throws Exception {
		return true;
	}

	/**
	* このフィルタの文字列表現を返します。
	* @return	このフィルタの文字列表現
	*/
	public String toString() {
		String ret = super.toString();
		ret += ",source=[";
		for ( int i = 0; i < vecSrc.size(); i++ ) {
			if ( i > 0 ) {
				ret += ",";
			}
			ret += vecSrc.get( i );
		}
		ret += "]";
		return ret;
	}
}
