package	jp.co.sds_corp.transfer.output;

import java.io.Serializable;
import java.rmi.Remote;
import java.rmi.RemoteException;

import jp.co.sds_corp.transfer.IDataKey;
import jp.co.sds_corp.transfer.IReceiveListener;
import jp.co.sds_corp.transfer.ReceiveEvent;

/**
* RMIの受信オブジェクトを定義するインターフェースです。
*/
public interface IRMIAdapter extends Remote, Serializable
{
	/**
	* データ受信を受け取るオブジェクトを追加します。
	* @param	l		データ受信を受け取るオブジェクト
	*/
	public void addReceiveListener( IReceiveListener l )
		throws RemoteException;
	/**
	* データ受信を受け取るオブジェクトを削除します。
	* @param	l		データ受信を受け取るオブジェクト
	*/
	public void removeReceiveListener( IReceiveListener l )
		throws RemoteException;
	/**
	* データ受信を受け取るオブジェクトを追加します。
	* @param	key		対象のキー
	* @param	l		データ受信を受け取るオブジェクト
	*/
	public void addReceiveListener( IDataKey key, IReceiveListener l )
		throws RemoteException;
	/**
	* データ受信を受け取るオブジェクトを削除します。
	* @param	key		対象のキー
	* @param	l		データ受信を受け取るオブジェクト
	*/
	public void removeReceiveListener( IDataKey key, IReceiveListener l )
		throws RemoteException;

	/**
	* データ受信イベントを通知します。
	* @param	e		データ受信イベント
	*/
	public void fireReceive( ReceiveEvent e )
		throws Exception;
}

