package	jp.co.sds_corp.transfer.source;

import java.io.File;
import java.io.FileInputStream;

import jp.co.sds_corp.util.common.CmnLog;
import jp.co.sds_corp.util.config.IConfiguration;

import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

/**
* Excelファイルからデータを受信するクラスの基底クラスです。
<PRE>
&lt;Source name="Excel" class="jp.co.sds_corp.transfer.source.ExcelSource"&gt;
	&lt;file&gt;data/test.xls&lt;/file&gt;
	&lt;sheet&gt;Shhet1&lt;/sheet&gt;
&lt;/Source&gt;
</PRE>
*/
public abstract class ExcelSource extends AbstractSource
{
	private static final long serialVersionUID = 1L;
	String	file;
	String	sheet;
	int		interval;
	transient Thread thr;

	/**
	* 指定された初期情報で初期化します。
	* @param	config	初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		file = config.get( "file" );
		sheet = config.get( "sheet" );
		interval = config.getInteger( "interval", 1000 );
		thr = new Thread( new ServiceThread() );
		thr.setName( getName() );
	}

	/**
	* このサービスを開始します。
	*/
	public void start() {
		setInterrupt( false );
		thr.start();
	}

	/**
	* このサービスを停止します。
	*/
	public void stop() {
		setInterrupt( true );
		thr.interrupt();
		try {
			thr.join();
		} catch ( Exception e ) {
		}
		CmnLog.debug( this, "stopped." );
	}

	/**
	* 読み込んだ行の内容を解析します。
	* @param	sheet	シートの内容
	*/
	public abstract void parseSheet( HSSFSheet sheet ) throws Exception;

	private void readFile() throws Exception {
		File f = new File( file );
		FileInputStream is = new FileInputStream( f );

		try {
			HSSFWorkbook workBook = new HSSFWorkbook( is );
			HSSFSheet Sheet = workBook.getSheet( sheet );
			parseSheet( Sheet );
		} finally {
			try {
				is.close();
			} catch ( Exception ex ) {
			}
		}
	}

	private class ServiceThread implements Runnable
	{
		public ServiceThread() {
		}

		public void run() {
			for ( ;; ) {
				if ( isInterrupted()) {
					break;
				}
				try {
					readFile();
				} catch ( Exception ex ) {
					CmnLog.error( this, "error", ex );
				}
				try {
					Thread.sleep( interval );
				} catch ( InterruptedException ie ) {
					break;
				}
			}
		}

	}

	/**
	* この取得元の文字列表現を返します。
	* @return	この取得元の文字列表現
	*/
	public String toString() {
		String ret = super.toString();
		ret += ":file=[" + file + "]" + " sheet=[" + sheet + "]"
				+ " interval=[" + interval + "]";
		return ret;
	}

}
